import 'dart:async';

import 'package:flutter/services.dart';

/// Manipulate iOS app icon badges
///
/// Alwayd check if badges are supported using [isBadgeSupported].
///
/// To set the badge immediately use [setBadge]. If you want to
/// schedule an update at a specific time, use [scheduleBadge]
/// which returns the `uuid` for that update.
///
class ScheduleBadgeUpdates {
  static const MethodChannel _channel =
      const MethodChannel('schedule_badge_updates');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// Clear the badge immediately.
  static Future<bool> clearBadge() async {
    return await _channel.invokeMethod('clearBadge');
  }

  /// Set the badge immediately.
  static Future<bool> setBadge(int badgeNr) async {
    return await _channel.invokeMethod('setBadge', badgeNr);
  }

  /// Check if badges are supported using
  static Future<bool> isBadgeSupported() async {
    return await _channel.invokeMethod('isBadgeSupported');
  }

  /// Set the app icon badge at a given time.
  static Future<String> scheduleBadge(int badgeNr, DateTime date) async {
    String outp = await _channel.invokeMethod('scheduleBadge', {
      "badge": badgeNr,
      "date": {
        "year": date.year,
        "month": date.month,
        "day": date.day,
        "hour": date.hour,
        "minute": date.minute,
        "second": date.second,
      }
    });
    return outp;
  }

  /// Remove scheduled badge updates corresponding to passed list of
  /// uuids.
  static Future<dynamic> unscheduleBadgeUpdates(List<String> uuids) async {
    return await _channel
        .invokeMethod('unscheduleBadgeUpdates', {"uuids": uuids});
  }

  /// Remove all scheduled badge updates.
  static Future<dynamic> unscheduleAllBadgeUpdates() async {
    return await _channel.invokeMethod('unscheduleAllBadgeUpdates');
  }
}
